/*
 * Copyright 2013 aquenos GmbH.
 * All rights reserved.
 * 
 * This program and the accompanying materials are made available under the 
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 */

package com.aquenos.csstudio.archive.json.reader;

import org.csstudio.archive.reader.ArchiveReader;
import org.csstudio.archive.reader.ArchiveReaderFactory;

/**
 * Factory for {@link JsonArchiveReader} instances. This class is exposed by an
 * extension, so that other plug-ins will automatically use for archive URLs
 * starting with "json:".
 * 
 * @author Sebastian Marsching
 */
public class JsonArchiveReaderFactory implements ArchiveReaderFactory {

    @Override
    public ArchiveReader getArchiveReader(String url) throws Exception {
        if (!url.startsWith("json:")) {
            throw new IllegalArgumentException(
                    "URL must start with scheme \"json:\".");
        }
        return new JsonArchiveReader(url);
    }

}
